'use client';
import { Fragment, memo, useId } from 'react';
import { Swiper, SwiperSlide } from "swiper/react";
import { Autoplay, Pagination } from "swiper/modules";
import "swiper/css";
import 'swiper/css/autoplay';
import style from './WhatChorelessGivesYou.module.css';

const Slide = memo(function Slide({ img }: {img: number}){
	const chat_id = useId();

	function mouseEnter(){
		const chats = (document.getElementById(chat_id) as HTMLDivElement).children;
		let delay = 0;
		for(const p of chats){
			(p as HTMLParagraphElement).style.transition =`transform 200ms ${delay}ms`;
			(p as HTMLParagraphElement).style.transform = 'scale(1)';
			delay+=190;
		}
	}

	function mouseLeave(){
		const chats = (document.getElementById(chat_id) as HTMLDivElement).children;
		for(const p of chats){
			(p as HTMLParagraphElement).style.transition =`transform 0s 0s`;
			(p as HTMLParagraphElement).style.transform = 'scale(0)';
		}
	}

	const conversations = [
		{ initiator: 'other', letter:'M', message: "What's the science project on and when's it's due?" },
		{ initiator: 'self', letter:'', message: "He wants to make a water rocket. Next Wednesday! Yikes." },
		{ initiator: 'other', letter:'M', message: "No worries. I'll find what you need ASAP." },
		{ initiator: 'self', letter:'', message: "🙌" },
	]
	let delay = -190;

	return (
		<div className={`mx-2 h-full relative rounded-xl shadow-lg ${style.container}`} onMouseEnter={mouseEnter} onMouseLeave={mouseLeave}>
			<img src={`https://ik.imagekit.io/choreless/v2/images/home/what_choreless_gives_you_${img}`} alt='image' loading='lazy' className="w-full h-full rounded-xl opacity-60" />
			<div className="flex flex-col justify-end gap-y-2 h-full pb-3 absolute bottom-0 px-5">
				<img src='https://ik.imagekit.io/choreless/v2/icons/FigmaRight2.svg' alt='icon' loading='lazy' className="w-5" />
				<h2 className="text-white text-2xl font-bold">Spend Time For Yourself</h2>
				<p className="text-white text-xs">Whatever you do, Family always comes first, so Give more time to your family, let choreless Take care of your laundry</p>
			</div>
			<div className="absolute bottom-0 h-full w-full rounded-xl pt-12 invisible cursor-grab">
				<div className="grid grid-cols-[auto_1fr] items-end ms-8 me-5 gap-x-2 gap-y-2" id={chat_id}>
					{
						conversations.map((v, k)=>{
							delay+=190;
							const x= <p className={v.initiator==='other' ? 'bg-[#1A1A1A] w-9 h-9 rounded-full text-white flex items-center justify-center font-bold' : undefined} style={{transform: 'scale(0)', transition: `transform 200ms ${delay}ms`}}>{v.letter}</p>;
							delay+=190;
							const y = <p className={'bg-white rounded-lg py-2 px-3 ' + (v.initiator=='other' ? '' : 'w-fit ms-auto')} style={{transform: 'scale(0)', transformOrigin: v.initiator==='other' ? '0% 90%' : '100% 90%', transition: `transform 200ms ${delay}ms`}}>{v.message}</p>;
							return <Fragment key={k}>
								{x}
								{y}
							</Fragment>
						})
					}
				</div>
			</div>
		</div>
	)
});

export default function WhatChorelessGivesYou(){
	return (
		<section className="bg-neutral-100 mt-[50px] pt-12 pb-0">
			<h1 className="text-center text-slate-900 text-4xl font-bold leading-10">What Choreless<br/>Gives you</h1>
			<p className="text-center text-slate-900 px-6 mt-4 max-w-[370px] mx-auto">Let’s say your son has a science project due, your kids need haircuts, and you really want to convert the garage into a playroom.</p>

			<div className='mt-5'>
				<Swiper
					modules={[Autoplay, Pagination]}
					autoplay={{
						delay: 1500,
						pauseOnMouseEnter: true
					}}
					slidesPerView='auto'
					loop
					className="h-[480px] w-full"
				>
					<SwiperSlide style={{width: '310px'}}><Slide img={1} /></SwiperSlide>
					<SwiperSlide style={{width: '310px'}}><Slide img={2} /></SwiperSlide>
					<SwiperSlide style={{width: '310px'}}><Slide img={3} /></SwiperSlide>
					<SwiperSlide style={{width: '310px'}}><Slide img={1} /></SwiperSlide>
					<SwiperSlide style={{width: '310px'}}><Slide img={2} /></SwiperSlide>
					<SwiperSlide style={{width: '310px'}}><Slide img={3} /></SwiperSlide>
					<SwiperSlide style={{width: '310px'}}><Slide img={1} /></SwiperSlide>
					<SwiperSlide style={{width: '310px'}}><Slide img={2} /></SwiperSlide>
					<SwiperSlide style={{width: '310px'}}><Slide img={3} /></SwiperSlide>
					<SwiperSlide style={{width: '310px'}}><Slide img={1} /></SwiperSlide>
					<SwiperSlide style={{width: '310px'}}><Slide img={2} /></SwiperSlide>
					<SwiperSlide style={{width: '310px'}}><Slide img={3} /></SwiperSlide>
				</Swiper>
			</div>
		</section>
	)
}
